#[non_exhaustive]pub struct ElasticOutlierResult {
pub outlier_indices: Vec<usize>,
pub distances: Vec<f64>,
pub threshold: f64,
pub amplitude_distances: Vec<f64>,
pub phase_distances: Vec<f64>,
}Expand description
Result of elastic outlier detection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.outlier_indices: Vec<usize>Indices of detected outlier curves.
distances: Vec<f64>Total elastic distance from each curve to the reference (length n).
threshold: f64Cutoff distance (Tukey fence: Q3 + 1.5 * IQR).
amplitude_distances: Vec<f64>Amplitude component of elastic distance for each curve (length n).
phase_distances: Vec<f64>Phase component of elastic distance for each curve (length n).