#[non_exhaustive]pub struct PartialMatchResult {
pub start_index: usize,
pub end_index: usize,
pub gamma: Vec<f64>,
pub distance: f64,
pub domain_fraction: f64,
}Expand description
Result of elastic partial matching.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_index: usizeStart index in the target curve where the best match begins.
end_index: usizeEnd index (inclusive) in the target curve where the best match ends.
gamma: Vec<f64>Warping function mapping template domain to the matched subdomain.
distance: f64Elastic distance of the best partial match.
domain_fraction: f64Fraction of the target domain spanned by the match.