Module auto_select

Module auto_select 

Automatic basis type and parameter selection.

Structs

BasisAutoSelectionResult
Result of automatic basis selection for all curves.
SingleCurveSelection
Result of automatic basis selection for a single curve.

Functions

select_basis_auto_1d
Select optimal basis type and parameters for each curve individually.