CovKernel

Enum CovKernel 

#[non_exhaustive]
pub enum CovKernel { Gaussian { length_scale: f64, variance: f64, }, Exponential { length_scale: f64, variance: f64, }, Matern { length_scale: f64, variance: f64, nu: f64, }, Brownian { variance: f64, }, Periodic { length_scale: f64, variance: f64, period: f64, }, Linear { variance: f64, offset: f64, }, Polynomial { variance: f64, offset: f64, degree: u32, }, WhiteNoise { variance: f64, }, Sum(Box<CovKernel>, Box<CovKernel>), Product(Box<CovKernel>, Box<CovKernel>), }
Covariance kernel specification.

Each variant encodes a family of covariance functions k(s, t). Kernels can be composed with Sum and Product to build richer covariance structures.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Gaussian

Squared-exponential (RBF) kernel: variance * exp(-0.5 * ((s-t)/length_scale)^2).

Fields

length_scale: f64
variance: f64


Exponential

Exponential (Ornstein-Uhlenbeck) kernel: variance * exp(-|s-t| / length_scale).

Fields

length_scale: f64
variance: f64


Matern

Matern kernel with smoothness parameter nu.

Closed-form expressions are used for nu = 0.5 (exponential), nu = 1.5, and nu = 2.5. For other values of nu the general formula with a gamma-function approximation is used.

Fields

length_scale: f64
variance: f64
nu: f64


Brownian

Brownian motion (Wiener process) kernel: variance * min(s, t).

Fields

variance: f64


Periodic

Periodic kernel: variance * exp(-2 * sin^2(pi * |s-t| / period) / length_scale^2).

Fields

length_scale: f64
variance: f64
period: f64


Linear

Linear kernel: variance * (s - offset) * (t - offset).

Fields

variance: f64
offset: f64


Polynomial

Polynomial kernel: (variance * s * t + offset)^degree.

Fields

variance: f64
offset: f64
degree: u32


WhiteNoise

White noise kernel: variance * delta(s, t).

Fields

variance: f64


Sum(Box<CovKernel>, Box<CovKernel>)

Sum of two kernels: k1(s,t) + k2(s,t).



Product(Box<CovKernel>, Box<CovKernel>)

Product of two kernels: k1(s,t) * k2(s,t).

Implementations

Source

impl CovKernel

pub fn eval(&self, s: f64, t: f64) -> f64

Evaluate the covariance function k(s, t).