Module elastic_regression

Module elastic_regression 

Elastic regression models (alignment-integrated regression).

These models from fdasrvf align curves during the regression fitting process, jointly optimizing alignment and regression coefficients.

Key capabilities:

Re-exports

pub use logistic::elastic_logistic;
pub use logistic::elastic_logistic_with_config;
pub use logistic::predict_elastic_logistic;
pub use logistic::ElasticLogisticResult;
pub use pcr::elastic_pcr;
pub use pcr::elastic_pcr_with_config;
pub use pcr::ElasticPcrResult;
pub use regression::elastic_regression;
pub use regression::elastic_regression_with_config;
pub use regression::predict_elastic_regression;
pub use regression::ElasticRegressionResult;
pub use scalar_on_shape::predict_scalar_on_shape;
pub use scalar_on_shape::scalar_on_shape;
pub use scalar_on_shape::ScalarOnShapeResult;

Modules

logistic
Elastic logistic regression for binary classification.
pcr
Elastic principal component regression.
regression
Elastic scalar-on-function regression.
scalar_on_shape
Scalar-on-Shape (ScoSh) regression.

Structs

ElasticConfig
Configuration for elastic_regression and elastic_logistic.
ElasticPcrConfig
Configuration for elastic_pcr.
ScalarOnShapeConfig
Configuration for scalar_on_shape().

Enums

IndexMethod
Index function method for scalar-on-shape regression.
PcaMethod
PCA method for elastic PCR.