#[non_exhaustive]pub struct FrechetGlobalRegResult {
pub predicted: FdMatrix,
pub xout: FdMatrix,
pub x_bar: Vec<f64>,
}Expand description
Result of global Fréchet regression (frechet_global_reg).
Predicts a conditional Fréchet-mean density response at each xout row via the
Petersen–Müller global linear weight scheme.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.predicted: FdMatrixPredicted density responses, shape n_out × m (row i = prediction at xout row i).
xout: FdMatrixThe predictor values predictions were made at, shape n_out × p.
x_bar: Vec<f64>Column means of the training predictors, length p.