Module kernels

Module kernels 

Kernel functions and mean estimation for irregular functional data.

Enums

KernelType
Kernel function type for smoothing operations.

Functions

mean_irreg
Estimate mean function at specified target points using kernel smoothing.