Module scalar_on_function

Module scalar_on_function 

Scalar-on-function regression with mixed scalar/functional covariates.

Implements models of the form:

y = α + ∫β(t)X(t)dt + γᵀz + ε

where X(t) is a functional predictor, z is a vector of scalar covariates, β(t) is the functional coefficient, and γ is the vector of scalar coefficients.

Methods

  • fregre_lm: FPC-based functional linear model with optional scalar covariates
  • fregre_l1: L1 (median) robust functional regression via IRLS
  • fregre_huber: Huber M-estimation robust functional regression via IRLS
  • fregre_np_mixed: Nonparametric kernel regression with product kernels
  • functional_logistic: Logistic regression for binary outcomes
  • fregre_cv: Cross-validation for number of FPC components

Structs

BootstrapCiResult
Result of bootstrap confidence intervals for β(t).
FregreBasisCvResult
Result of lambda selection for basis regression via cross-validation.
FregreCvResult
Result of cross-validation for K selection.
FregreLmResult
Result of functional linear regression.
FregreNpCvResult
Result of bandwidth selection for nonparametric regression via CV.
FregreNpResult
Result of nonparametric functional regression with mixed predictors.
FregreRobustResult
Result of robust (L1 or Huber) functional regression.
FunctionalLogisticResult
Result of functional logistic regression.
ModelSelectionResult
Result of ncomp model selection.

Enums

SelectionCriterion
Criterion used for model selection.

Functions

bootstrap_ci_fregre_lm
Bootstrap confidence intervals for β(t) from a functional linear model.
bootstrap_ci_functional_logistic
Bootstrap confidence intervals for β(t) from a functional logistic model.
fregre_basis_cv
K-fold CV for selecting the regularization parameter lambda in basis-regression (R’s fregre.basis.cv).
fregre_cv
K-fold cross-validation for selecting the number of FPC components.
fregre_huber
Huber M-estimation functional regression via FPCA + IRLS.
fregre_l1
L1 (median) functional regression via FPCA + IRLS.
fregre_lm
Functional linear model with optional scalar covariates.
fregre_np_cv
K-fold CV for selecting the bandwidth in functional nonparametric regression (R’s fregre.np.cv).
fregre_np_mixed
Nonparametric kernel regression with mixed functional and scalar predictors.
functional_logistic
Functional logistic regression for binary outcomes.
model_selection_ncomp
Select optimal ncomp for fregre_lm using AIC, BIC, or GCV.
predict_fregre_lm
Predict new responses using a fitted functional linear model.
predict_fregre_np
Predict new responses using a fitted nonparametric model.
predict_fregre_robust
Predict new responses using a fitted robust functional regression model.
predict_functional_logistic
Predict probabilities P(Y=1) for new data using a fitted functional logistic model.