#[non_exhaustive]pub enum GlmFamily {
Binomial,
Poisson,
Gamma,
Gaussian,
}Expand description
Exponential-family distribution for functional_glm.
Each variant specifies the canonical link function and variance function for one member of the exponential family.
| Variant | Link g(μ) | Inverse link g⁻¹(η) | Variance V(μ) |
|---|---|---|---|
| Binomial | logit | sigmoid | μ(1−μ) |
| Poisson | log | exp | μ |
| Gamma | inverse | 1/η | μ² |
| Gaussian | identity | η | 1 |
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Binomial
Logit link; binary outcomes (y ∈ {0, 1}).
Poisson
Log link; non-negative integer counts (y ∈ {0, 1, 2, …}).
Gamma
Inverse link (canonical); strictly positive continuous responses (y > 0).
Gaussian
Identity link; continuous unbounded responses.