#[non_exhaustive]pub struct FrccChart {
pub fosr: FosrResult,
pub residual_fpca: FpcaResult,
pub eigenvalues: Vec<f64>,
pub t2_limit: ControlLimit,
pub spe_limit: ControlLimit,
pub fosr_r_squared: f64,
pub config: FrccConfig,
}Expand description
Phase I FRCC chart.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fosr: FosrResultFitted FOSR model.
residual_fpca: FpcaResultFPCA on calibration residuals.
eigenvalues: Vec<f64>Eigenvalues from residual FPCA.
t2_limit: ControlLimitT-squared control limit.
spe_limit: ControlLimitSPE control limit.
fosr_r_squared: f64Coefficient of determination (R²) for the FOSR model on the tuning set. Values near 0 suggest the predictors explain little variance, and the FRCC may not add value over a standard SPM chart.
config: FrccConfigConfiguration used.