PhaseToleranceBand

Struct PhaseToleranceBand 

#[non_exhaustive]
pub struct PhaseToleranceBand { pub gamma_lower: Vec<f64>, pub gamma_upper: Vec<f64>, pub gamma_center: Vec<f64>, pub tangent_band: ToleranceBand, }
Phase tolerance band on warping functions.

Provides bounds on acceptable timing variation by mapping FPCA tolerance bands from the tangent space of the Hilbert sphere back to warping functions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
gamma_lower: Vec<f64>

Lower bound warping function (length m).

gamma_upper: Vec<f64>

Upper bound warping function (length m).

gamma_center: Vec<f64>

Center (identity) warping function (length m).

tangent_band: ToleranceBand

Tolerance band in tangent (shooting vector) space.