Module depth

Module depth 

Depth measures for functional data.

This module provides various depth measures for assessing the centrality of functional observations within a reference sample.

Re-exports

pub use band::band_1d;
pub use band::modified_band_1d;
pub use band::modified_epigraph_index_1d;
pub use dispatch::functional_boxplot;
pub use dispatch::functional_depth;
pub use dispatch::DepthMethod;
pub use dispatch::FunctionalBoxplotResult;
pub use erl::extreme_rank_length_depth_1d;
pub use extremal::extremal_depth_1d;
pub use fraiman_muniz::fraiman_muniz_1d;
pub use fraiman_muniz::fraiman_muniz_2d;
pub use half_region::half_region_depth_1d;
pub use half_region::modified_half_region_depth_1d;
pub use hypo_epi::epigraph_index_1d;
pub use hypo_epi::hypograph_index_1d;
pub use hypo_epi::modified_hypograph_index_1d;
pub use linf::linfinity_depth_1d;
pub use modal::modal_1d;
pub use modal::modal_2d;
pub use random_projection::random_projection_1d;
pub use random_projection::random_projection_1d_seeded;
pub use random_projection::random_projection_2d;
pub use random_tukey::random_tukey_1d;
pub use random_tukey::random_tukey_1d_seeded;
pub use random_tukey::random_tukey_2d;
pub use rpd::rpd_depth_1d;
pub use rpd::rpd_depth_1d_seeded;
pub use spatial::functional_spatial_1d;
pub use spatial::functional_spatial_2d;
pub use spatial::kernel_functional_spatial_1d;
pub use spatial::kernel_functional_spatial_2d;
pub use tvd::total_variation_depth_1d;
pub use tvd::TvdMssResult;

Modules

band
Band depth and related measures (BD, MBD, MEI).
dispatch
Unified depth dispatcher and depth-fence functional boxplot.
erl
Extreme-rank-length (ERL) depth.
extremal
Extremal depth (Narisetty & Nair 2016).
fraiman_muniz
Fraiman-Muniz depth measures.
half_region
Half-region depth and modified half-region depth (HRD, MHRD).
hypo_epi
Hypograph, modified-hypograph, and epigraph indices (HI, MHI, EI).
linf
L∞ (sup-norm) depth.
modal
Modal depth measures.
random_projection
Random projection depth measures.
random_tukey
Random Tukey depth measures.
rpd
Random Projection with Derivatives (RPD) depth.
spatial
Functional spatial depth measures (FSD and KFSD).
tvd
Total variation depth with modified shape similarity index (TVD + MSSI).