Depth measures for functional data.
This module provides various depth measures for assessing the centrality of functional observations within a reference sample.
Re-exports
pub use band::band_1d;pub use band::modified_band_1d;pub use band::modified_epigraph_index_1d;pub use fraiman_muniz::fraiman_muniz_1d;pub use fraiman_muniz::fraiman_muniz_2d;pub use modal::modal_1d;pub use modal::modal_2d;pub use random_projection::random_projection_1d;pub use random_projection::random_projection_1d_seeded;pub use random_projection::random_projection_2d;pub use random_tukey::random_tukey_1d;pub use random_tukey::random_tukey_1d_seeded;pub use random_tukey::random_tukey_2d;pub use rpd::rpd_depth_1d;pub use rpd::rpd_depth_1d_seeded;pub use spatial::functional_spatial_1d;pub use spatial::functional_spatial_2d;pub use spatial::kernel_functional_spatial_1d;pub use spatial::kernel_functional_spatial_2d;
Modules
- band
- Band depth and related measures (BD, MBD, MEI).
- fraiman_
muniz - Fraiman-Muniz depth measures.
- modal
- Modal depth measures.
- random_
projection - Random projection depth measures.
- random_
tukey - Random Tukey depth measures.
- rpd
- Random Projection with Derivatives (RPD) depth.
- spatial
- Functional spatial depth measures (FSD and KFSD).