Detrending and decomposition functions for non-stationary functional data.
This module provides methods for removing trends from functional data to enable more accurate seasonal analysis. It includes:
- Linear detrending (least squares)
- Polynomial detrending (QR decomposition)
- Differencing (first and second order)
- LOESS detrending (local polynomial regression)
- Spline detrending (P-splines)
- Automatic method selection via AIC
Structs
- Decompose
Result - Result of seasonal decomposition.
- StlResult
- Result of STL decomposition including robustness weights.
- Trend
Result - Result of detrending operation.
Functions
- auto_
detrend - Automatically select the best detrending method using AIC.
- decompose_
additive - Additive seasonal decomposition: data = trend + seasonal + remainder
- decompose_
multiplicative - Multiplicative seasonal decomposition: data = trend * seasonal * remainder
- detrend_
diff - Remove trend by differencing.
- detrend_
linear - Remove linear trend from functional data using least squares.
- detrend_
loess - Remove trend using LOESS (local polynomial regression).
- detrend_
polynomial - Remove polynomial trend from functional data using QR decomposition.
- stl_
decompose - STL Decomposition: Seasonal and Trend decomposition using LOESS
- stl_
fdata - Wrapper function for functional data STL decomposition.