Scalar-on-function regression with mixed scalar/functional covariates.
Implements models of the form:
y = α + ∫β(t)X(t)dt + γᵀz + εwhere X(t) is a functional predictor, z is a vector of scalar covariates, β(t) is the functional coefficient, and γ is the vector of scalar coefficients.
Methods
fregre_lm: FPC-based functional linear model with optional scalar covariatesfregre_l1: L1 (median) robust functional regression via IRLSfregre_huber: Huber M-estimation robust functional regression via IRLSfregre_np_mixed: Nonparametric kernel regression with product kernelsfunctional_logistic: Logistic regression for binary outcomesfregre_cv: Cross-validation for number of FPC components
Structs
- Bootstrap
CiResult - Result of bootstrap confidence intervals for β(t).
- Fregre
Basis CvResult - Result of lambda selection for basis regression via cross-validation.
- Fregre
CvResult - Result of cross-validation for K selection.
- Fregre
LmResult - Result of functional linear regression.
- Fregre
NpCv Result - Result of bandwidth selection for nonparametric regression via CV.
- Fregre
NpResult - Result of nonparametric functional regression with mixed predictors.
- Fregre
Robust Result - Result of robust (L1 or Huber) functional regression.
- Functional
Logistic Result - Result of functional logistic regression.
- Model
Selection Result - Result of ncomp model selection.
Enums
- Selection
Criterion - Criterion used for model selection.
Functions
- bootstrap_
ci_ fregre_ lm - Bootstrap confidence intervals for β(t) from a functional linear model.
- bootstrap_
ci_ functional_ logistic - Bootstrap confidence intervals for β(t) from a functional logistic model.
- fregre_
basis_ cv - K-fold CV for selecting the regularization parameter lambda
in basis-regression (R’s
fregre.basis.cv). - fregre_
cv - K-fold cross-validation for selecting the number of FPC components.
- fregre_
huber - Huber M-estimation functional regression via FPCA + IRLS.
- fregre_
l1 - L1 (median) functional regression via FPCA + IRLS.
- fregre_
lm - Functional linear model with optional scalar covariates.
- fregre_
np_ cv - K-fold CV for selecting the bandwidth in functional nonparametric
regression (R’s
fregre.np.cv). - fregre_
np_ mixed - Nonparametric kernel regression with mixed functional and scalar predictors.
- functional_
logistic - Functional logistic regression for binary outcomes.
- model_
selection_ ncomp - Select optimal ncomp for
fregre_lmusing AIC, BIC, or GCV. - predict_
fregre_ lm - Predict new responses using a fitted functional linear model.
- predict_
fregre_ np - Predict new responses using a fitted nonparametric model.
- predict_
fregre_ robust - Predict new responses using a fitted robust functional regression model.
- predict_
functional_ logistic - Predict probabilities P(Y=1) for new data using a fitted functional logistic model.